==> kv5500-0.1.tar.gz: kv5500-0.1/src/kv5500_photo.hpp <==
/*****************************************************************************
 *
 *  kv5500_photo - read a photo from kv5500 like phone.
 *
 * Copyright (c) 2006 Hyo geol, Lee
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *
 *   1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 *   3. The name of the author may not be used to endorse or promote products
 * derived from this software without specific prior written permission.
 *
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 *
 ****************************************************************************/
#ifndef KV5500_PHOTO_H
#define KV5500_PHOTO_H

#include <string>
#include <vector>

#include <exception>

#include "scanner.hpp"

namespace KV5500 {

    class UsbDev;

    class PhotoInfo {
    public:
        PhotoInfo(const std::string& name, unsigned int size);

        const std::string& GetName() const;
        unsigned int GetFileSize() const;

        void SetName(const char* str);
        void SetSize(unsigned int size);

    private:
        std::string name_;
        unsigned int fileSize_;
    };

    class PhotoInfoScanner : public Scanner {
    public:
        PhotoInfoScanner();

        void GetPhotoInfo(std::vector<PhotoInfo>& vec) const;
        unsigned int GetPhotoInfoNum() const;

    private:
        std::vector<PhotoInfo> photoInfoContainer_;

        PhotoInfoScanner(const PhotoInfoScanner&);
        PhotoInfoScanner& operator=(const PhotoInfoScanner&);

        bool DoScan(struct usb_device* dev);

        bool Request(UsbDev& udev);
    };

    class PhotoGetNum : public std::exception {
        const char* what() const throw();
    };

    class PhotoGetFileScanner : public Scanner {
    public:
        PhotoGetFileScanner(unsigned int num);

    private:
        const unsigned int num_;

        PhotoGetFileScanner(const PhotoGetFileScanner&);
        PhotoGetFileScanner& operator=(const PhotoGetFileScanner&);

        bool DoScan(struct usb_device* dev);

        bool CheckPhotoNum(UsbDev& udev) const;
        std::string GetFilename() const;

        bool PutPhotoFile(UsbDev& udev);
    };

    unsigned int GetRevEndian(char* buf);

    int RecvPhotoName(UsbDev& udev, std::string& photoName);
    int RecvPhotoFileSize(UsbDev& udev, unsigned int& size);

    bool GetTotalPhotoNum(UsbDev& udev, unsigned int& num);

    bool SendPrepareTransferPhoto(UsbDev& udev);

    void PrintTransferProcess(unsigned int complete, unsigned int total);

    bool HasSubstStr(const char* const buf, const unsigned int pos);

    unsigned int GetPrefixPos(const char* const buf);
    unsigned int GetPostfixPos(const char* const buf, const unsigned int bufSize);

    void GetPhotoInfo(std::vector<PhotoInfo>& vec);
    void SavePhotoFile(unsigned int num);
}

/// inline functions.
using namespace KV5500;

inline PhotoInfo::PhotoInfo(const std::string& name, unsigned int size)
    : name_(name),
      fileSize_(size)
{}

inline const std::string& PhotoInfo::GetName() const
{
    return name_;
}

inline unsigned int PhotoInfo::GetFileSize() const
{
    return fileSize_;
}

inline void PhotoInfo::SetName(const char* str)
{
    name_ = str;
}

inline void PhotoInfo::SetSize(unsigned int size)
{
    fileSize_ = size;
}

inline PhotoInfoScanner::PhotoInfoScanner()
{}

inline void PhotoInfoScanner::GetPhotoInfo(std::vector<PhotoInfo>& vec) const
{
    vec = photoInfoContainer_;
}

inline unsigned int PhotoInfoScanner::GetPhotoInfoNum() const
{
    return photoInfoContainer_.size();
}

inline PhotoGetFileScanner::PhotoGetFileScanner(unsigned int num)
    : num_(num)
{
    if(num == 0 || num > 256)
        throw PhotoGetNum();
}

inline unsigned int KV5500::GetRevEndian(char* buf)
{
    assert(buf);

    return static_cast<unsigned char>(buf[0]) + 
        (static_cast<unsigned char>(buf[1]) << 8) + 
        (static_cast<unsigned char>(buf[2]) << 16) +
        (static_cast<unsigned char>(buf[3]) << 24);
}

inline void KV5500::PrintTransferProcess(unsigned int complete, unsigned int total)
{
    printf("\r%d / %d (%.2f%%)", complete, total, 100.0 * complete / total);
}

inline bool KV5500::HasSubstStr(const char* const buf, const unsigned int pos)
{
    assert(buf);

    return static_cast<unsigned char>(buf[pos]) == 0x7d &&
        (static_cast<unsigned char>(buf[pos + 1]) == 0x5e ||
         static_cast<unsigned char>(buf[pos + 1]) == 0x5d);
}

inline unsigned int KV5500::GetPostfixPos(const char* const buf, const unsigned int bufSize)
{
    assert(buf && bufSize > 4);

    return HasSubstStr(buf, bufSize - 4) || HasSubstStr(buf, bufSize -3) ? 4 : 3;
}

#endif

==> kv5500-0.2.tar.gz: kv5500-0.2/src/kv5500_photo.hpp <==
/*****************************************************************************
 *
 *  kv5500_photo - read a photo from kv5500 like phone.
 *
 * Copyright (c) 2006 Hyo geol, Lee
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *
 *   1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 *   3. The name of the author may not be used to endorse or promote products
 * derived from this software without specific prior written permission.
 *
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 *
 ****************************************************************************/
#ifndef KV5500_PHOTO_H
#define KV5500_PHOTO_H

#include "kv5500_file.hpp"

namespace KV5500 {

    class PhotoInfoScanner : public FileInfoScanner {
    public:
        PhotoInfoScanner();

    private:
        PhotoInfoScanner(const PhotoInfoScanner&);
        PhotoInfoScanner& operator=(const PhotoInfoScanner&);
    };

    class PhotoGetFileScanner : public GetFileScanner {
    public:
        PhotoGetFileScanner(unsigned int num);

    private:
        PhotoGetFileScanner(const PhotoGetFileScanner&);
        PhotoGetFileScanner& operator=(const PhotoGetFileScanner&);

        std::string GetFilename() const;
    };

    void GetPhotoInfo(std::vector<FileInfo>& vec);
    void SavePhotoFile(unsigned int num);
}

#endif
